@@ -1,6 +1,7 @@
 import {
   GET_VM,
   GET_BY_PAGE,
+  GET_OPTION,
   GET_USB_FILTER,
   PERSIST_STATE,
   SET_ADMINISTATOR,
@@ -102,3 +103,19 @@ export function getUSBFilter () {
     payload: {},
   }
 }
+
+/**
+ * @param {string} optionName
+ * @param {OptionVersionType} version option version
+ * @param {string=} defaultValue
+ */
+export function getOption (optionName, version, defaultValue) {
+  return {
+    type: GET_OPTION,
+    payload: {
+      optionName,
+      version,
+      defaultValue,
+    },
+  }
+}
