@@ -8,27 +8,26 @@ import { fixedStrings } from '../branding'
 
 const OvirtApiCheckFailed = ({ config }) => {
   const oVirtApiVersion = config.get('oVirtApiVersion')
-  console.log(`OvirtApiCheckFailed(): ${JSON.stringify(oVirtApiVersion.toJS())}`)
 
   const passed = oVirtApiVersion.get('passed')
   if (passed !== false) { // if unknown, the test has not finished yet
     return null
   }
 
-  let found = msg.quotedUnknown()
+  console.info(`OvirtApiCheckFailed(): ${JSON.stringify(oVirtApiVersion.toJS())}`)
+
   const major = oVirtApiVersion.get('major')
   const minor = oVirtApiVersion.get('minor')
-  if (major) {
-    found = `${major}.${minor}`
-  }
+  const version = major ? `${major}.${minor}` : `"${msg.unknown()}"`
 
   const required = `${Product.ovirtApiVersionRequired.major}.${Product.ovirtApiVersionRequired.minor}`
 
   return (
     <div className='alert alert-danger'>
       <span className='pficon pficon-error-circle-o' />
-      <strong>{msg.unsupportedOvirtVersionFound({ version: found, productName: fixedStrings.BRAND_NAME })}</strong>,&nbsp;
-      {msg.butVersionAtLeastRequired({ requiredVersion: required })}.
+      <span
+        id='ovirtapi-check-failed'
+        dangerouslySetInnerHTML={{ __html: msg.htmlUnsupportedOvirtVersionFoundButVersionAtLeastRequired({ version, productName: fixedStrings.BRAND_NAME, requiredVersion: required }) }} />
     </div>
   )
 }
