@@ -4,10 +4,13 @@ import { CONSOLE_IN_USE } from './constants'
 import { setConsoleInUse } from './actions'
 
 function* getConsoleInUseModal (sagas, action) {
-  let { vmId, usbFilter } = action.payload
+  let { vmId, usbFilter, userId } = action.payload
   const sessionsInternal = yield sagas.fetchVmSessions({ vmId })
   if (sessionsInternal &&
-    sessionsInternal.find((x) => x.consoleUser) !== undefined) {
+    sessionsInternal.find(
+      (x) => x.consoleUser &&
+            (!userId || x.user.id === userId)
+      ) !== undefined) {
     yield put(setConsoleInUse({ vmId, consoleInUse: true }))
   } else {
     yield put(downloadConsole({ vmId, usbFilter }))
