@@ -1,6 +1,8 @@
 // Keep alphabetically sorted
 // TODO: sort alphabetically
 // TODO: remove all constants except those used within sagas
+export const CHANGE_VM_ICON = 'CHANGE_VM_ICON'
+export const CHANGE_VM_ICON_BY_ID = 'CHANGE_VM_ICON_BY_ID'
 export const CHECK_TOKEN_EXPIRED = 'CHECK_TOKEN_EXPIRED'
 export const CLEAR_USER_MSGS = 'CLEAR_USER_MSGS'
 export const DOWNLOAD_CONSOLE_VM = 'DOWNLOAD_CONSOLE_VM'
@@ -13,6 +15,7 @@ export const GET_ALL_TEMPLATES = 'GET_ALL_TEMPLATES'
 export const GET_BY_PAGE = 'GET_BY_PAGE'
 export const GET_CONSOLE_OPTIONS = 'GET_CONSOLE_OPTIONS'
 export const GET_ISO_STORAGES = 'GET_ISO_STORAGES'
+export const GET_OPTION = 'GET_OPTION'
 export const GET_POOL = 'GET_POOL'
 export const GET_POOLS_BY_COUNT = 'GET_POOLS_BY_COUNT'
 export const GET_POOLS_BY_PAGE = 'GET_POOLS_BY_PAGE'
